==> qtwallet_1.4-8maemo1.tar.gz: qtwallet-1.4/src/QLabelImage.h <==
/*
 * Copyright (c) 2010 David Galindo <nowheremanmail@gmail.com>
 */

#ifndef QLABELIMAGE_H
#define QLABELIMAGE_H

#include <QtGui>
#include <QDebug>
#include "DatabaseManager.h"
#include "ImageViewer.h"

class QLabelImage: public QLabel {
	Q_OBJECT
public:
	QLabelImage(QWidget *parent=0, Qt::WindowFlags f=0);
	~QLabelImage();

	void setPicture (QImage * i);
	void setPicture (TargetField * field);
	QImage * getImage ();

signals:
	void clicked ();

protected:
    void mouseDoubleClickEvent(QMouseEvent *);

private slots:
    void windowViewerDestroyed(QObject* obj);
    void seePicture ();

private:
    QImage * image;
    QPointer<ImageViewer> viewerWindow;
};

//class QLabelImage: public QWidget {
//	Q_OBJECT
//public:
//	QLabelImage(QWidget *parent=0, Qt::WindowFlags f=0);
//	~QLabelImage();
//
//	void setPixmap (const QPixmap &);
//
//signals:
//	void clicked ();
//
//protected:
//    void mouseDoubleClickEvent(QMouseEvent *);
//    void timerEvent(QTimerEvent *event);
//    //bool event(QEvent *event);
//    void mousePressEvent(QMouseEvent *);
//    void mouseReleaseEvent(QMouseEvent *);
//    //void mouseDoubleClickEvent ( QMouseEvent * event );
//
//private:
//	QLabel * label;
//	QVBoxLayout * layout;
//	QScrollArea * entryScrollArea;
//	bool mode;
//
//private:
//	int tickTimer;
//	double factor;
//	int tick;
//	QSize sizec;
//
//	inline void recalculate () {
//		if (label->pixmap()->width() <= 800 && label->pixmap()->height() > 400)
//			factor = 400 / label->pixmap()->height();
//		else
//		if (label->pixmap()->width() > 800 && label->pixmap()->height() <= 400)
//			factor = 800 / label->pixmap()->width();
//		else
//		if (label->pixmap()->width() < 800 && label->pixmap()->height() < 400) {
//			double x2 = factor = 800 / label->pixmap()->width();
//			double x1 = factor = 400 / label->pixmap()->height();
//
//			factor = x1 > x2 ? x1 : x2;
//		}
//		else
//			factor = 1.0;
//	}
//
//};


#endif // QLABELIMAGE_H

==> qtwallet_1.4-9maemo1.tar.gz: qtwallet-1.4/src/QLabelImage.h <==
/*
 * Copyright (c) 2010 David Galindo <nowheremanmail@gmail.com>
 */

#ifndef QLABELIMAGE_H
#define QLABELIMAGE_H

#include <QtGui>
#include <QDebug>
#include "DatabaseManager.h"
#include "ImageViewer.h"

class QLabelImage: public QLabel {
	Q_OBJECT
public:
	QLabelImage(QWidget *parent=0, Qt::WindowFlags f=0);
	~QLabelImage();

	void setPicture (QImage * i);
	void setPicture (TargetField * field);
	QImage * getImage ();

signals:
	void clicked(QImage *);

protected:
    void mouseDoubleClickEvent(QMouseEvent *);

private:
    QImage * image;
};

//class QLabelImage: public QWidget {
//	Q_OBJECT
//public:
//	QLabelImage(QWidget *parent=0, Qt::WindowFlags f=0);
//	~QLabelImage();
//
//	void setPixmap (const QPixmap &);
//
//signals:
//	void clicked ();
//
//protected:
//    void mouseDoubleClickEvent(QMouseEvent *);
//    void timerEvent(QTimerEvent *event);
//    //bool event(QEvent *event);
//    void mousePressEvent(QMouseEvent *);
//    void mouseReleaseEvent(QMouseEvent *);
//    //void mouseDoubleClickEvent ( QMouseEvent * event );
//
//private:
//	QLabel * label;
//	QVBoxLayout * layout;
//	QScrollArea * entryScrollArea;
//	bool mode;
//
//private:
//	int tickTimer;
//	double factor;
//	int tick;
//	QSize sizec;
//
//	inline void recalculate () {
//		if (label->pixmap()->width() <= 800 && label->pixmap()->height() > 400)
//			factor = 400 / label->pixmap()->height();
//		else
//		if (label->pixmap()->width() > 800 && label->pixmap()->height() <= 400)
//			factor = 800 / label->pixmap()->width();
//		else
//		if (label->pixmap()->width() < 800 && label->pixmap()->height() < 400) {
//			double x2 = factor = 800 / label->pixmap()->width();
//			double x1 = factor = 400 / label->pixmap()->height();
//
//			factor = x1 > x2 ? x1 : x2;
//		}
//		else
//			factor = 1.0;
//	}
//
//};


#endif // QLABELIMAGE_H
